@@ -1,6 +1,7 @@
 from django import http
 from django.template import RequestContext, loader
 
+
 def server_error(request, template_name='500.html'):
     """
     500 error handler.
@@ -10,5 +11,9 @@ def server_error(request, template_name='500.html'):
         request_path
             The path of the requested URL (e.g., '/app/pages/bad_page/')
     """
-    t = loader.get_template(template_name) # You need to create a 500.html template.
-    return http.HttpResponseServerError(t.render(RequestContext(request, {'request_path': request.path})))
+
+    # You need to create a 500.html template.
+    t = loader.get_template(template_name)
+
+    return http.HttpResponseServerError(
+        t.render(RequestContext(request, {'request_path': request.path})))
